==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dav/l10n/sr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "Подсетници",
    "Personal" : "Лично",
    "{actor} created calendar {calendar}" : "{actor} је направио календар {calendar}",
    "You created calendar {calendar}" : "Креирали сте календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} је обрисао календар {calendar}",
    "You deleted calendar {calendar}" : "Обрисали сте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} је ажурирао календар {calendar}",
    "You updated calendar {calendar}" : "Ажурирали сте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Поделили сте календар {calendar} као јавну везу",
    "You removed public link for calendar {calendar}" : "Уклонили сте јавну везу за календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} је поделио календар {calendar} са вама",
    "You shared calendar {calendar} with {user}" : "Поделили сте календар {calendar} са {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} је поделио календар {calendar} са {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} је укинуо дељење календара {calendar} са вама",
    "You unshared calendar {calendar} from {user}" : "Укинули сте дељење календара {calendar} са {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} је укинуо дељење календара {calendar} са {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} је укинуо дељење календара {calendar} од себе",
    "You shared calendar {calendar} with group {group}" : "Поделили сте календар {calendar} са групом {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} је поделио календар {calendar} са групом {group}",
    "You unshared calendar {calendar} from group {group}" : "Укинули сте дељење календара {calendar} са групом {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} је укинуо дељење календара {calendar} са групом {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} је направио догађај {event} у календару {calendar}",
    "You created event {event} in calendar {calendar}" : "Креирали сте догађај {event} у календару {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} је обрисао догађај {event} из календара {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Обрисали сте догађај {event} из календара {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} је ажурирао догађај {event} у календару {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ажурирали сте догађај {event} у календару {calendar}",
    "Busy" : "Заузет/а",
    "{actor} created todo {todo} in list {calendar}" : "{actor} је направио подсетник {todo} у листи {calendar}",
    "You created todo {todo} in list {calendar}" : "Креирали сте подсетник {todo}  у листи {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Обрисали сте подсетник {todo} из листе {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} је ажурирао подсетник {todo}  у листи {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ажурирали сте подсетник {todo} у листи {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You solved todo {todo} in list {calendar}" : "Маркирали сте подсетник {todo} као готов у листи {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} је поново отворио подсетник {todo} у листи {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Поново сте отворили подсетник {todo}  у листи {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> је измењен",
    "A calendar <strong>event</strong> was modified" : "<strong>Догађај</strong> из календара је измењен",
    "A calendar <strong>todo</strong> was modified" : "<strong>Подсетник</strong> из календара је измењен",
    "Death of %s" : " %s смрт",
    "Contact birthdays" : "Рођендани контаката",
    "Calendar:" : "Календар:",
    "Date:" : "Датум:",
    "Where:" : "Место:",
    "Description:" : "Опис:",
    "Untitled event" : "Неименовани догађај",
    "_%n year_::_%n years_" : ["%n година","%n године","%n  година"],
    "_%n month_::_%n months_" : ["%n месец","%n месеца","%n месеци"],
    "_%n day_::_%n days_" : ["%n дан","%n дана","%n дана"],
    "_%n hour_::_%n hours_" : ["%n сат","%n сата","%n сати"],
    "_%n minute_::_%n minutes_" : ["%n минут","%n минута","%n минута"],
    "%s (in %s)" : "%s (у %s)",
    "%s (%s ago)" : "%s (пре %s)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Датум: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Место: %s",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "Invitation canceled" : "Позивница отказана",
    "Hello %s," : "Здраво %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Састанак „%1$s“ са  %2$s је отказан.",
    "Invitation updated" : "Позивница ажурирана",
    "The meeting »%1$s« with %2$s was updated." : "Састанак „%1$s“ са %2$s је ажуриран.",
    "%1$s invited you to »%2$s«" : "%1$s Вас је позвао на „%2$s“",
    "When:" : "Време:",
    "Link:" : "Веза:",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "More options …" : "Још опција…",
    "More options at %s" : "Још опција на %s",
    "Contacts" : "Контакти",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s мора да буде подешен да користи HTTPS да бисте користи CalDAV и CardDAV са iOS/macOS-ом.",
    "Configures a CalDAV account" : "Подешава CalDAV налог",
    "Configures a CardDAV account" : "Подешава CardDAV налог",
    "WebDAV" : "ВебДАВ",
    "WebDAV endpoint" : "WebDAV крајња тачка",
    "Technical details" : "Технички детаљи",
    "Remote Address: %s" : "Удаљена адреса: %s",
    "Request ID: %s" : "ИД захтева: %s",
    "There was an error updating your attendance status." : "Десила се грешка приликом ажурирања статуса Вашег присуства.",
    "Please contact the organizer directly." : "Контактирајте директно организатора.",
    "Are you accepting the invitation?" : "Да ли прихватате позивницу?",
    "Tentative" : "Условна потврда",
    "Save" : "Сачувај",
    "Your attendance was updated successfully." : "Ваше присуство је успешно ажурирано.",
    "Calendar server" : "Календар сервера",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Такође инсталирајте {calendarappstoreopen}Календар апликацију{linkclose}, или {calendardocopen}повежите Ваш рачунар & мобилни за синхронизацију ↗{linkclose}.",
    "Send invitations to attendees" : "Пошаљи позивницу учесницима",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Постарајте се да правилно подесите {emailopen}сервер е-поште{linkclose}.",
    "Automatically generate a birthday calendar" : "Аутоматски изгенериши календар рођендана",
    "Birthday calendars will be generated by a background job." : "Календари рођендана ће бити генерисани као позадински послови.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Зато можда неће бити видљиви баш одмах по укључивању, али ће се појавити после неког времена.",
    "Send notifications for events" : "Шаљи обавештења о догађајима",
    "Notifications are sent via background jobs, so these must occur often enough." : "Обавештења се шаљу кроз послове у позадини, па би требало да су постављени да се често извршавају.",
    "Enable notifications for events via push" : "Укључи обавештења за догађаје преко гурања догађаја",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Обавештења ће бити слана кроз послове у позадини, па би требало да су они постављени да се често извршавају."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-21.0.1-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dav/l10n/sr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "Подсетници",
    "Personal" : "Лично",
    "{actor} created calendar {calendar}" : "{actor} направи календар {calendar}",
    "You created calendar {calendar}" : "Направили сте календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} обриса календар {calendar}",
    "You deleted calendar {calendar}" : "Обрисали сте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ажурира календар {calendar}",
    "You updated calendar {calendar}" : "Ажурирали сте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Поделили сте календар {calendar} као јавну везу",
    "You removed public link for calendar {calendar}" : "Уклонили сте јавну везу за календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} подели календар {calendar} са вама",
    "You shared calendar {calendar} with {user}" : "Поделили сте календар {calendar} са корисником {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} подели календар {calendar} са корисником {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} укину дељење календара {calendar} са вама",
    "You unshared calendar {calendar} from {user}" : "Укинули сте дељење календара {calendar} са корисником {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} укину дељење календара {calendar} кориснику {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} укину дељење календара {calendar} са њим",
    "You shared calendar {calendar} with group {group}" : "Поделили сте календар {calendar} са групом {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} подели календар {calendar} са групом {group}",
    "You unshared calendar {calendar} from group {group}" : "Укинули сте дељење календара {calendar} са групом {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} укину дељење календара {calendar} са групом {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} је направио догађај {event} у календару {calendar}",
    "You created event {event} in calendar {calendar}" : "Креирали сте догађај {event} у календару {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} је обрисао догађај {event} из календара {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Обрисали сте догађај {event} из календара {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} је ажурирао догађај {event} у календару {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ажурирали сте догађај {event} у календару {calendar}",
    "Busy" : "Заузет/а",
    "{actor} created todo {todo} in list {calendar}" : "{actor} је направио подсетник {todo} у листи {calendar}",
    "You created todo {todo} in list {calendar}" : "Креирали сте подсетник {todo}  у листи {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Обрисали сте подсетник {todo} из листе {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} је ажурирао подсетник {todo}  у листи {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ажурирали сте подсетник {todo} у листи {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You solved todo {todo} in list {calendar}" : "Маркирали сте подсетник {todo} као готов у листи {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} је поново отворио подсетник {todo} у листи {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Поново сте отворили подсетник {todo}  у листи {calendar}",
    "Calendar and tasks" : "Календар и задаци",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> је измењен",
    "A calendar <strong>event</strong> was modified" : "<strong>Догађај</strong> из календара је измењен",
    "A calendar <strong>todo</strong> was modified" : "<strong>Подсетник</strong> из календара је измењен",
    "Contact birthdays" : "Рођендани контаката",
    "Death of %s" : " %s смрт",
    "Calendar:" : "Календар:",
    "Date:" : "Датум:",
    "Where:" : "Место:",
    "Description:" : "Опис:",
    "Untitled event" : "Неименовани догађај",
    "_%n year_::_%n years_" : ["%n година","%n године","%n  година"],
    "_%n month_::_%n months_" : ["%n месец","%n месеца","%n месеци"],
    "_%n day_::_%n days_" : ["%n дан","%n дана","%n дана"],
    "_%n hour_::_%n hours_" : ["%n сат","%n сата","%n сати"],
    "_%n minute_::_%n minutes_" : ["%n минут","%n минута","%n минута"],
    "%s (in %s)" : "%s (у %s)",
    "%s (%s ago)" : "%s (пре %s)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Датум: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Место: %s",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "Invitation canceled" : "Позивница отказана",
    "Invitation updated" : "Позивница ажурирана",
    "Invitation" : "Позивница",
    "Title:" : "Наслов:",
    "Time:" : "Време:",
    "Location:" : "Локација:",
    "Link:" : "Веза:",
    "Organizer:" : "Организатор:",
    "Attendees:" : "Присутни:",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "More options …" : "Још опција…",
    "More options at %s" : "Још опција на %s",
    "Contacts" : "Контакти",
    "System in maintenance mode." : "Систем у режиму одржавања.",
    "Upgrade needed" : "Потребна надградња",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s мора да буде подешен да користи HTTPS да бисте користи CalDAV и CardDAV са iOS/macOS-ом.",
    "Configures a CalDAV account" : "Подешава CalDAV налог",
    "Configures a CardDAV account" : "Подешава CardDAV налог",
    "Events" : "Догађаји",
    "Tasks" : "Задаци",
    "Untitled task" : "Неименовани задатак",
    "Completed on %s" : "Завршено %s",
    "Due on %s by %s" : "Рок је %s од стране %s",
    "Due on %s" : "Рок је %s",
    "WebDAV" : "ВебДАВ",
    "WebDAV endpoint" : "WebDAV крајња тачка",
    "There was an error updating your attendance status." : "Десила се грешка приликом ажурирања статуса Вашег присуства.",
    "Please contact the organizer directly." : "Контактирајте директно организатора.",
    "Are you accepting the invitation?" : "Да ли прихватате позивницу?",
    "Tentative" : "Условна потврда",
    "Save" : "Сачувај",
    "Your attendance was updated successfully." : "Ваше присуство је успешно ажурирано.",
    "Calendar server" : "Календар сервера",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Такође инсталирајте {calendarappstoreopen}Календар апликацију{linkclose}, или {calendardocopen}повежите Ваш рачунар & мобилни за синхронизацију ↗{linkclose}.",
    "Send invitations to attendees" : "Пошаљи позивницу учесницима",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Постарајте се да правилно подесите {emailopen}сервер е-поште{linkclose}.",
    "Automatically generate a birthday calendar" : "Аутоматски изгенериши календар рођендана",
    "Birthday calendars will be generated by a background job." : "Календари рођендана ће бити генерисани као позадински послови.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Зато можда неће бити видљиви баш одмах по укључивању, али ће се појавити после неког времена.",
    "Send notifications for events" : "Шаљи обавештења о догађајима",
    "Notifications are sent via background jobs, so these must occur often enough." : "Обавештења се шаљу кроз послове у позадини, па би требало да су постављени да се често извршавају.",
    "Enable notifications for events via push" : "Укључи обавештења за догађаје преко гурања догађаја",
    "Hello %s," : "Здраво %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Састанак „%1$s“ са  %2$s је отказан.",
    "The meeting »%1$s« with %2$s was updated." : "Састанак „%1$s“ са %2$s је ажуриран.",
    "%1$s invited you to »%2$s«" : "%1$s Вас је позвао на „%2$s“",
    "When:" : "Време:"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
